@@ -22,7 +22,7 @@ use vars qw($VERSION %samsungLensTypes);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.37';
+$VERSION = '1.39';
 
 sub WriteSTMN($$$);
 sub ProcessINFO($$$);
@@ -86,12 +86,14 @@ my %formatMinMax = (
         DataTag => 'PreviewImage',
         IsOffset => 3,
         Protected => 2,
+        WriteGroup => 'MakerNotes',
     },
     3 => {
         Name => 'PreviewImageLength',
         OffsetPair => 2,   # point to associated offset
         DataTag => 'PreviewImage',
         Protected => 2,
+        WriteGroup => 'MakerNotes',
     },
     11 => {
         Name => 'SamsungIFD',
@@ -275,7 +277,7 @@ my %formatMinMax = (
         Writable => 'int16u',
         SubDirectory => { TagTable => 'Image::ExifTool::Samsung::PictureWizard' },
     },
-    # 0x0022 - int32u (CaptureMode?)
+    # 0x0022 - int32u (CaptureMode?) (Gamma? eg. 65538 = 1.2, ref forum7720)
     # 0x0023 - string: "0123456789" (PH) (placeholder for SerialNumber?)
     # 0x0025 - int32u (ImageCount?)
     # 0x002a - undef[4] (SNSDirectShare?)
@@ -908,7 +910,7 @@ my %formatMinMax = (
     4 => { Name => 'ThumbnailOffset', IsOffset => 1 },
 );
 
-# information extracted from Samsung trailer (ie. Samsung SM-T805 "Sound & Shot" JPEG)
+# information extracted from Samsung trailer (ie. Samsung SM-T805 "Sound & Shot" JPEG) (ref PH)
 %Image::ExifTool::Samsung::Trailer = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Other' },
     VARS => { NO_ID => 1 },
@@ -918,23 +920,49 @@ my %formatMinMax = (
         as the Galaxy S4 and Tab S.
     },
     # stuff written with "Shot & More" feature
-    '0x0001' => { Name => 'EmbeddedImage', Groups => { 2 => 'Preview' }, Binary => 1 },
     '0x0001-name' => 'EmbeddedImageName',
-    # 0x0830 - unknown (164004 bytes, name like "1165724808.pre")
-
+    '0x0001' => { Name => 'EmbeddedImage', Groups => { 2 => 'Preview' }, Binary => 1 },
     # stuff written with "Sound & Shot" feature
-    '0x0100' => { Name => 'EmbeddedAudioFile', Binary => 1 },
     '0x0100-name' => 'EmbeddedAudioFileName',
-    # 0x0800 - SoundShot_Meta_Info (contains only already-extracted sound shot name)
+    '0x0100' => { Name => 'EmbeddedAudioFile', Binary => 1 },
+   # 0x0800-name - seen 'SoundShot_Meta_Info'
+   # 0x0800 - (contains only already-extracted sound shot name)
+   # 0x0830-name - seen '1165724808.pre'
+   # 0x0830 - unknown (164004 bytes)
+   # 0x09e0-name - seen 'Burst_Shot_Info'
+   # 0x09e0 - seen '489489125'
+   # 0x0a01-name - seen 'Image_UTC_Data'
     '0x0a01' => { #forum7161
         Name => 'TimeStamp',
         Groups => { 2 => 'Time' },
         ValueConv => 'ConvertUnixTime($val / 1e3, 1)',
         PrintConv => '$self->ConvertDateTime($val)',
     },
-    #'0x0a01-name' = "Image_UTC_Data"
-    '0x0a30' => { Name => 'EmbeddedVideoFile', Binary => 1 }, #forum7161
     '0x0a30-name' => 'EmbeddedVideoType', # ("MotionPhoto_Data")
+    '0x0a30' => { Name => 'EmbeddedVideoFile', Binary => 1 }, #forum7161
+   # 0x0aa1-name - seen 'MCC_Data'
+   # 0x0aa1 - seen '234'
+    '0x0ab1-name' => 'DepthMapName', # seen 'DualShot_DepthMap_1' (SM-N950U)
+    '0x0ab1' => { Name => 'DepthMapData', Binary => 1 },
+   # 0x0ab3-name - seen 'DualShot_Extra_Info' (SM-N950U)
+    '0x0ab3' => { # (SM-N950U)
+        Name => 'DualShotInfo',
+        SubDirectory => { TagTable => 'Image::ExifTool::Samsung::DualShotInfo' },
+     },
+   # 0x0ac0-name - seen 'ZoomInOut_Info' (SM-N950U)
+   # 0x0ac0 - 2048 bytes of interesting stuff including firmware version? (SM-N950U)
+   # 0xa050-name - seen 'Jpeg360_2D_Info' (Samsung Gear 360)
+   # 0xa050 - seen 'Jpeg3602D' (Samsung Gear 360)
+);
+
+# DualShot Extra Info (ref PH)
+%Image::ExifTool::Samsung::DualShotInfo = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 0 => 'MakerNotes', 2 => 'Image' },
+    FIRST_ENTRY => 0,
+    FORMAT => 'int32u',
+    9 => 'DepthMapWidth',
+    10 => 'DepthMapHeight',
 );
 
 # Samsung composite tags
@@ -952,6 +980,18 @@ my %formatMinMax = (
             return "@a";
         },
     },
+    DepthMapTiff => {
+        Require => {
+            0 => 'DepthMapData',
+            1 => 'DepthMapWidth',
+            2 => 'DepthMapHeight',
+        },
+        ValueConv => q{
+            return undef unless length ${$val[0]} == $val[1] * $val[2];
+            my $tiff = MakeTiffHeader($val[1],$val[2],1,8) . ${$val[0]};
+            return \$tiff;
+        },
+    }
 );
 
 # add our composite tags
@@ -1242,7 +1282,7 @@ Samsung maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
